#version 330 core

layout (location = 0) in vec3 aPos;
layout (location = 1) in vec2 aTexCoord;
layout (location = 2) in vec4 aColor;
layout (location = 3) in vec2 aBTexCoord;

uniform mat4 modelView;
uniform mat4 proj;
uniform mat4 projInv;
uniform vec4 viewport;
uniform vec4 fogColor;
uniform vec2 fogStartEnd;
uniform float fogDensity;
uniform vec3 renderOffset;
uniform int isFog;

out vec2 TexCoord;
out vec2 BTexCoord;
out vec4 Color;
out vec4 Viewport;
out mat4 ProjInv;
out vec4 FogColor;
out vec2 FogStartEnd;
out float FogFactor;

out float DistanceToCamera;
flat out int IsFogg;

void main()
{
	vec4 worldPos = vec4(aPos, 1.0) + vec4(renderOffset.x, renderOffset.y + 0.12, renderOffset.z, 0);
	gl_Position = proj * modelView * worldPos;

	TexCoord = aTexCoord;
	BTexCoord = aBTexCoord;
	Color = aColor;
	Viewport = viewport;
	ProjInv = projInv;

	FogColor = fogColor;

	if(fogStartEnd.x >= 0 && fogStartEnd.y >= 0){
		float s = fogStartEnd.x;
		float e = fogStartEnd.y;
		float c = length(worldPos);
		float fogFactor = clamp((e - c) / (e - s), 0, 1);
		FogFactor = fogFactor;
	} else {
		FogFactor = -1;
	}
	FogStartEnd = fogStartEnd;

/*	FogColor = fogColor;
	IsFogg = isFog;

	if (isFog == 1) {
		DistanceToCamera = length(worldPos);

		float fogFactor = exp(fogDensity * DistanceToCamera);
		FogFactor = fogFactor;

		FogStartEnd = fogStartEnd;
	}*/
}
